import re

def fillTemplate(template: str, replacements: dict):
    def convert(m):
        placeholder = m.group(1)

        if placeholder not in replacements:
            raise Exception('Value for placeholder {' + placeholder + '} not defined')

        return str(replacements[placeholder])

    return re.sub(r'\{([^\}]+)\}', convert, template)



from box import Box
from jobsbundle.git.CurrentBranchResolver import CurrentBranchResolver
from jobsbundle.job.fillTemplate import fillTemplate

class ValuesFiller:

    def __init__(
        self,
        currentBranchResolver: CurrentBranchResolver,
    ):
        self.__currentBranchResolver = currentBranchResolver

    def fill(self, template: dict, values: dict, identifier: str) -> Box:
        values['identifier'] = identifier
        values['currentBranch'] = self.__currentBranchResolver.resolve()

        def fillDictTemplate(value):
            if isinstance(value, dict):
                return {k: fillDictTemplate(v) for k, v in value.items()}

            if isinstance(value, list):
                return list(map(fillDictTemplate, value))

            if isinstance(value, str):
                return fillTemplate(value, values)

            return value

        return Box({k: fillDictTemplate(v) for k, v in template.items()})



from consolebundle.ConsoleBundle import ConsoleBundle
from injecta.config.YamlConfigReader import YamlConfigReader
from injecta.container.ContainerInterface import ContainerInterface
from injecta.package.pathResolver import resolvePath
from typing import List
from pyfony.kernel.BaseKernel import BaseKernel
from pyfonybundles.Bundle import Bundle
from jobsbundle.JobsBundle import JobsBundle

def initContainer(appEnv) -> ContainerInterface:
    class Kernel(BaseKernel):

        def _registerBundles(self) -> List[Bundle]:
            return [
                ConsoleBundle(),
                JobsBundle()
            ]

    kernel = Kernel(
        appEnv,
        resolvePath('jobsbundle') + '/_config',
        YamlConfigReader()
    )

    return kernel.initContainer()



import unittest
from injecta.testing.servicesTester import testServices
from jobsbundle.containerInit import initContainer

class JobsBundleTest(unittest.TestCase):

    def setUp(self) -> None:
        self.__container = initContainer('test')

    def test_init(self):
        testServices(self.__container)

if __name__ == '__main__':
    unittest.main()
